@@ -1,9 +1,14 @@
 from rest_framework.test import APIRequestFactory, force_authenticate
 
-from .request import RequestTestCase
+from .request import BaseRequestTestCase
 
 
-class APIRequestTestCase(RequestTestCase):
+class BaseAPIRequestTestCase(BaseRequestTestCase):
+    """
+    Extend BaseRequestTestCase with REST framework compatibility.
+
+    Must be subclassed with an user_factory attribute in order to work.
+    """
     request_factory = APIRequestFactory
 
     def create_request(self, method='get', url='/', user=None, auth=True, **kwargs):
